==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/en-GB/general.php <==
<?php

    return [
    'accessories'			=> 'Accessories',
    'activated'			    => 'Activated',
    'accessory'				=> 'Accessory',
    'accessory_report'		=> 'Accessory Report',
    'action'                => 'Action',
    'activity_report'		=> 'Activity Report',
    'address'				=> 'Address',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Added seats',
    'all_assets'			=> 'All Assets',
    'all'       			=> 'All',
    'archived'              => 'Archived',
    'asset_models'			=> 'Asset Models',
    'asset_model'			=> 'Model',
    'asset'					=> 'Asset',
    'asset_report'          => 'Asset Report',
    'asset_tag'				=> 'Asset Tag',
    'assets_available'		=> 'assets available',
    'audit'				    => 'Audit',
    'audit_report'			=> 'Audit Log',
    'assets'				=> 'Assets',
    'avatar_delete'         => 'Delete Avatar',
    'avatar_upload'         => 'Upload Avatar',
    'back'      			=> 'Back',
    'bad_data'      		=> 'Nothing found. Maybe bad data?',
    'bulkaudit'             => 'Bulk Audit',
    'bulkaudit_status'      => 'Audit Status',
    'bulk_checkout'  		=> 'Bulk Checkout',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Cancel',
    'categories'			=> 'Categories',
    'category'				=> 'Category',
    'change' 		        => 'In/Out',
    'changeemail'  			=> 'Change Email Address',
    'changepassword'  		=> 'Change Password',
    'checkin'  				=> 'Checkin',
    'checkin_from'  		=> 'Checkin from',
    'checkout'  			=> 'Checkout',
    'checkouts_count'       => 'Checkouts',
    'checkins_count'        => 'Checkins',
    'user_requests_count'   => 'Requests',
    'city'  				=> 'City',
	'click_here'			=> 'Click here',
    'clear_selection'		=> 'Clear Selection',
    'companies'			    => 'Companies',
    'company'				=> 'Company',
    'component'			    => 'Component',
    'components'			=> 'Components',
	'complete'				=> 'Complete',
    'consumable'			=> 'Consumable',
    'consumables'			=> 'Consumables',
    'country'  				=> 'Country',
    'create'				=> 'Create New',
    'created'               => 'Item Created',
    'created_asset'			=> 'created asset',
    'created_at' 			=> 'Created at',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Updated at',
    'currency'  			=> '£', // this is deprecated
    'current'  				=> 'Current',
    'custom_report'         => 'Custom Asset Report',
    'dashboard'				=> 'Dashboard',
    'days'      			=> 'days',
    'days_to_next_audit'    => 'Days to Next Audit',
    'date'					=> 'Date',
    'debug_warning'         => 'Warning!',
    'debug_warning_text'    => 'This application is running in production mode with debugging enabled. This can expose sensitive data if your application is accessible to the outside world. Disable debug mode by setting the <code>APP_DEBUG</code> value in your <code>.env</code> file to <code>false</code>.',
    'delete'  				=> 'Delete',
    'delete_confirm'  		=> 'Are you sure you wish to delete :item?',
    'deleted'  				=> 'Deleted',
    'delete_seats'  		=> 'Deleted Seats',
    'departments'           => 'Departments',
    'department'           => 'Department',
    'deployed'				=> 'Deployed',
    'depreciation_report'	=> 'Depreciation Report',
    'details'               => 'Details',
    'download'				=> 'Download',
    'download_all'				=> 'Download All',
    'depreciation'			=> 'Depreciation',
    'editprofile'  			=> 'Edit Your Profile',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Email Domain',
    'email_format'			=> 'Email Format',
    'email_domain_help'		=> 'This is used to generate email addresses when importing',
    'filastname_format'			=> 'First Initial Last Name (jsmith@example.com)',
    'firstname_lastname_format'	=> 'First Name Last Name (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'First Name Last Name (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Last Name First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'First',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'First Name',
    'first_name_format'		=> 'First Name (jane@example.com)',
    'files'                 => 'Files',
    'file_name'				=> 'File',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'File Uploads',
    'generate'				=> 'Generate',
     'github_markdown'      => 'This field accepts <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavoured markdown</a>.',
    'groups'				=> 'Groups',
    'gravatar_email'        => 'Gravatar Email Address',
    'history'  			    => 'History',
    'history_for'  			=> 'History for',
    'id'  					=> 'ID',
    'image'                 => 'Image',
    'image_delete'         	=> 'Delete Image',
    'image_upload'         	=> 'Upload Image',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Import',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Import History',
    'asset_maintenance'        => 'Asset Maintenance',
    'asset_maintenance_report' => 'Asset Maintenance Report',
    'asset_maintenances'       => 'Asset Maintenances',
    'item'  				=> 'Item',
    'insufficient_permissions' => 'Insufficient permissions!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Language',
    'last'					=> 'Last',
    'last_login'            => 'Last Login',
    'last_name'             => 'Last Name',
    'license'				=> 'License',
    'license_report'        => 'License Report',
    'licenses_available'	=> 'licenses available',
    'licenses'				=> 'Licenses',
    'list_all'				=> 'List All',
    'loading'				=> 'Loading',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'This feature has been disabled for the demo installation.',
    'location'              => 'Location',
    'locations'				=> 'Locations',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Logout',
    'lookup_by_tag'     => 'Lookup by Asset Tag',
    'maintenances'          => 'Maintenances',
    'manufacturer'			=> 'Manufacturer',
    'manufacturers'			=> 'Manufacturers',
    'markdown'				=> 'This field allows <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'min_amt'				=> 'Min. QTY',
    'min_amt_help'	=> 'Minimum number of items that should be available before an alert gets triggered.',
    'model_no'				=> 'Model No.',
    'months'				=> 'months',
    'moreinfo'				=> 'More Info',
    'name'					=> 'Name',
    'next'					=> 'Next',
    'next_audit_date'		=> 'Next Audit Date',
    'last_audit'		    => 'Last Audit',
    'new'					=> 'new!',
    'no_depreciation'		=> 'No Depreciation',
    'no_results'			=> 'No Results.',
    'no'  					=> 'No',
    'notes'  				=> 'Notes',
    'order_number'          => 'Order Number',
    'page_menu'				=> 'Showing _MENU_ items',
    'pagination_info'		=> 'Showing _START_ to _END_ of _TOTAL_ items',
    'pending'				=> 'Pending',
    'people'				=> 'People',
    'per_page'				=> 'Results Per Page',
    'previous'				=> 'Previous',
    'processing'			=> 'Processing',
    'profile'				=> 'Your profile',
    'purchase_cost'                              => 'Purchase Cost',
    'purchase_date'         => 'Purchase Date',
    'qty'		            => 'QTY',
    'quantity'		        => 'Quantity',
    'ready_to_deploy'		=> 'Ready to Deploy',
    'recent_activity'		=> 'Recent Activity',
    'remove_company'        => 'Remove Company Association',
    'reports'				=> 'Reports',
    'restored'				=> 'restored',
    'requested'				=> 'Requested',
    'request_canceled'      => 'Request Canceled',
    'save'  				=> 'Save',
    'select'				=> 'Select',
    'search'				=> 'Search',
    'select_category'       => 'Select a Category',
    'select_department'       => 'Select a Department',
    'select_depreciation'	=> 'Select a Depreciation Type',
    'select_location'		=> 'Select a Location',
    'select_manufacturer'	=> 'Select a Manufacturer',
    'select_model'			=> 'Select a Model',
    'select_supplier'		=> 'Select a Supplier',
    'select_user'			=> 'Select a User',
    'select_date'			=> 'Select Date (YYYY-MM-DD)',
    'select_statuslabel'	=> 'Select Status',
    'select_company'    	=> 'Select Company',
    'select_asset'    		=> 'Select Asset',
    'settings'				=> 'Settings',
    'show_deleted'  		=> 'Show Deleted',
    'show_current'  		=> 'Show Current',
    'sign_in'				=> 'Sign in',
    'signature'             => 'Signature',
    'skin'       			=> 'Skin',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'DEMO MODE: Some features are disabled for this installation.',
    'site_name'				=> 'Site Name',
    'state'  				=> 'State',
    'status_labels'			=> 'Status Labels',
    'status'    			=> 'Status',
    'supplier'              => 'Supplier',
    'suppliers'  			=> 'Suppliers',
    'sure_to_delete'    => 'Are you sure you wish to delete',
    'submit'				=> 'Submit',
    'target'                => 'Target',
    'time_and_date_display' => 'Time and Date Display',
    'total_assets'			=> 'total assets',
    'total_licenses'		=> 'total licenses',
    'total_accessories'		=> 'total accessories',
    'total_consumables'		=> 'total consumables',
    'type'  				=> 'Type',
    'undeployable'			=> 'Un-deployable',
    'unknown_admin'			=> 'Unknown Admin',
    'username_format'		=> 'Username Format',
    'update'                => 'Update',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Uploaded',
    'user'					=> 'User',
    'accepted'			    => 'accepted',
    'declined'			    => 'declined',
    'unaccepted_asset_report' => 'Unaccepted Assets',
    'users'                 => 'Users',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'View Assigned Assets',
    'website'               => 'Website',
    'welcome'				=> 'Welcome, :name',
    'years'					=> 'years',
    'yes' 					=> 'Yes',
    'zip'  					=> 'Zip',
    'noimage'				=> 'No image uploaded or image not found.',
    'token_expired'         => 'Your form session has expired. Please try again.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/en-GB/general.php <==
<?php

    return [
    'accessories'			=> 'Accessories',
    'activated'			    => 'Activated',
    'accessory'				=> 'Accessory',
    'accessory_report'		=> 'Accessory Report',
    'action'                => 'Action',
    'activity_report'		=> 'Activity Report',
    'address'				=> 'Address',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Added seats',
    'all_assets'			=> 'All Assets',
    'all'       			=> 'All',
    'archived'              => 'Archived',
    'asset_models'			=> 'Asset Models',
    'asset_model'			=> 'Model',
    'asset'					=> 'Asset',
    'asset_report'          => 'Asset Report',
    'asset_tag'				=> 'Asset Tag',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Assets available',
    'accept_assets'         => 'Accept Assets :name',
    'accept_assets_menu'    => 'Accept Assets',
    'audit'				    => 'Audit',
    'audit_report'			=> 'Audit Log',
    'assets'				=> 'Assets',
    'avatar_delete'         => 'Delete Avatar',
    'avatar_upload'         => 'Upload Avatar',
    'back'      			=> 'Back',
    'bad_data'      		=> 'Nothing found. Maybe bad data?',
    'bulkaudit'             => 'Bulk Audit',
    'bulkaudit_status'      => 'Audit Status',
    'bulk_checkout'  		=> 'Bulk Checkout',
    'bulk_edit'             => 'Bulk Edit',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Cancel',
    'categories'			=> 'Categories',
    'category'				=> 'Category',
    'change' 		        => 'In/Out',
    'changeemail'  			=> 'Change Email Address',
    'changepassword'  		=> 'Change Password',
    'checkin'  				=> 'Checkin',
    'checkin_from'  		=> 'Checkin from',
    'checkout'  			=> 'Checkout',
    'checkouts_count'       => 'Checkouts',
    'checkins_count'        => 'Checkins',
    'user_requests_count'   => 'Requests',
    'city'  				=> 'City',
    'click_here'			=> 'Click here',
    'clear_selection'		=> 'Clear Selection',
    'companies'			    => 'Companies',
    'company'				=> 'Company',
    'component'			    => 'Component',
    'components'			=> 'Components',
    'complete'				=> 'Complete',
    'consumable'			=> 'Consumable',
    'consumables'			=> 'Consumables',
    'country'  				=> 'Country',
    'create'				=> 'Create New',
    'created'               => 'Item Created',
    'created_asset'			=> 'created asset',
    'created_at' 			=> 'Created at',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Updated at',
    'currency'  			=> '£', // this is deprecated
    'current'  				=> 'Current',
    'current_password'      => 'Current Password',
    'customize_report'      => 'Customize Report',
    'custom_report'         => 'Custom Asset Report',
    'dashboard'				=> 'Dashboard',
    'days'      			=> 'days',
    'days_to_next_audit'    => 'Days to Next Audit',
    'date'					=> 'Date',
    'debug_warning'         => 'Warning!',
    'debug_warning_text'    => 'This application is running in production mode with debugging enabled. This can expose sensitive data if your application is accessible to the outside world. Disable debug mode by setting the <code>APP_DEBUG</code> value in your <code>.env</code> file to <code>false</code>.',
    'delete'  				=> 'Delete',
    'delete_confirm'  		=> 'Are you sure you wish to delete :item?',
    'deleted'  				=> 'Deleted',
    'delete_seats'  		=> 'Deleted Seats',
    'deletion_failed'       => 'Deletion failed',
    'departments'           => 'Departments',
    'department'            => 'Department',
    'deployed'				=> 'Deployed',
    'depreciation'			=> 'Depreciation',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Depreciation Report',
    'details'               => 'Details',
    'download'				=> 'Download',
    'download_all'		    => 'Download All',
    'editprofile'  			=> 'Edit Your Profile',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Email Domain',
    'email_format'			=> 'Email Format',
    'employee_number'       => 'Employee Number',
    'email_domain_help'		=> 'This is used to generate email addresses when importing',
    'error'				    => 'Error',
    'filastname_format'			=> 'First Initial Last Name (jsmith@example.com)',
    'firstname_lastname_format'	=> 'First Name Last Name (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'First Name Last Name (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Last Name First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'First',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'First Name',
    'first_name_format'		=> 'First Name (jane@example.com)',
    'files'                 => 'Files',
    'file_name'				=> 'File',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'File Uploads',
    'file_upload'           => 'File Upload',
    'generate'				=> 'Generate',
    'generate_labels'       => 'Generate Labels',
    'github_markdown'      => 'This field accepts <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavoured markdown</a>.',
    'groups'				=> 'Groups',
    'gravatar_email'        => 'Gravatar Email Address',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'History',
    'history_for'  			=> 'History for',
    'id'  					=> 'ID',
    'image'                 => 'Image',
    'image_delete'         	=> 'Delete Image',
    'image_upload'         	=> 'Upload Image',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Import',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Import History',
    'asset_maintenance'        => 'Asset Maintenance',
    'asset_maintenance_report' => 'Asset Maintenance Report',
    'asset_maintenances'       => 'Asset Maintenances',
    'item'  				=> 'Item',
    'item_name'             => 'Item Name',
    'insufficient_permissions' => 'Insufficient permissions!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Language',
    'last'					=> 'Last',
    'last_login'            => 'Last Login',
    'last_name'             => 'Last Name',
    'license'				=> 'License',
    'license_report'        => 'License Report',
    'licenses_available'	=> 'licenses available',
    'licenses'				=> 'Licenses',
    'list_all'				=> 'List All',
    'loading'				=> 'Loading... please wait....',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'This feature has been disabled for the demo installation.',
    'location'              => 'Location',
    'locations'				=> 'Locations',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Logout',
    'lookup_by_tag'     => 'Lookup by Asset Tag',
    'maintenances'          => 'Maintenances',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'Manufacturer',
    'manufacturers'			=> 'Manufacturers',
    'markdown'				=> 'This field allows <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'min_amt'				=> 'Min. QTY',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'Model No.',
    'months'				=> 'months',
    'moreinfo'				=> 'More Info',
    'name'					=> 'Name',
    'new_password'          => 'New Password',
    'next'					=> 'Next',
    'next_audit_date'		=> 'Next Audit Date',
    'last_audit'		    => 'Last Audit',
    'new'					=> 'new!',
    'no_depreciation'		=> 'No Depreciation',
    'no_results'			=> 'No Results.',
    'no'  					=> 'No',
    'notes'  				=> 'Notes',
    'order_number'          => 'Order Number',
    'page_menu'				=> 'Showing _MENU_ items',
    'pagination_info'		=> 'Showing _START_ to _END_ of _TOTAL_ items',
    'pending'				=> 'Pending',
    'people'				=> 'People',
    'per_page'				=> 'Results Per Page',
    'previous'				=> 'Previous',
    'processing'			=> 'Processing',
    'profile'				=> 'Your profile',
    'purchase_cost'                              => 'Purchase Cost',
    'purchase_date'         => 'Purchase Date',
    'qty'		            => 'QTY',
    'quantity'		        => 'Quantity',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Quick Scan Checkin',
    'quickscan_checkin_status'  	=> 'Checkin Status',
    'ready_to_deploy'		=> 'Ready to Deploy',
    'recent_activity'		=> 'Recent Activity',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Remove Company Association',
    'reports'				=> 'Reports',
    'restored'				=> 'restored',
    'restore'				=> 'Restore',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'Requested',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Request Canceled',
    'save'  				=> 'Save',
    'select'				=> 'Select',
    'select_all'            => 'Select All',
    'search'				=> 'Search',
    'select_category'       => 'Select a Category',
    'select_department'     => 'Select a Department',
    'select_depreciation'	=> 'Select a Depreciation Type',
    'select_location'		=> 'Select a Location',
    'select_manufacturer'	=> 'Select a Manufacturer',
    'select_model'			=> 'Select a Model',
    'select_supplier'		=> 'Select a Supplier',
    'select_user'			=> 'Select a User',
    'select_date'			=> 'Select Date (YYYY-MM-DD)',
    'select_statuslabel'	=> 'Select Status',
    'select_company'    	=> 'Select Company',
    'select_asset'    		=> 'Select Asset',
    'settings'				=> 'Settings',
    'show_deleted'  		=> 'Show Deleted',
    'show_current'  		=> 'Show Current',
    'sign_in'				=> 'Sign in',
    'signature'             => 'Signature',
    'skin'       			=> 'Skin',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'DEMO MODE: Some features are disabled for this installation.',
    'site_name'				=> 'Site Name',
    'state'  				=> 'State',
    'status_labels'			=> 'Status Labels',
    'status'    			=> 'Status',
    'supplier'              => 'Supplier',
    'suppliers'  			=> 'Suppliers',
    'sure_to_delete'    => 'Are you sure you wish to delete',
    'submit'				=> 'Submit',
    'target'                => 'Target',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Time and Date Display',
    'total_assets'			=> 'total assets',
    'total_licenses'		=> 'total licenses',
    'total_accessories'		=> 'total accessories',
    'total_consumables'		=> 'total consumables',
    'type'  				=> 'Type',
    'undeployable'			=> 'Un-deployable',
    'unknown_admin'			=> 'Unknown Admin',
    'username_format'		=> 'Username Format',
    'update'                => 'Update',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Uploaded',
    'user'					=> 'User',
    'accepted'			    => 'accepted',
    'declined'			    => 'declined',
    'unaccepted_asset_report' => 'Unaccepted Assets',
    'users'                 => 'Users',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'View Assigned Assets',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'Website',
    'welcome'				=> 'Welcome, :name',
    'years'					=> 'years',
    'yes' 					=> 'Yes',
    'zip'  					=> 'Zip',
    'noimage'				=> 'No image uploaded or image not found.',
    'token_expired'         => 'Your form session has expired. Please try again.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'accept_decline'        => 'Accept/Decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Step 1',
    'setup_step_2'          => 'Step 2',
    'setup_step_3'          => 'Step 3',
    'setup_step_4'          => 'Step 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Create Database Tables',
    'setup_create_admin'    => 'Create Admin User',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
